# Coverage

## testcoverage.yaml

- [testcoverage.yaml]
- Used by `coverage:` in
  - [go-test-darwin.yaml]
  - [go-test-linux.yaml]
  - [go-test-windows.yaml]
- [go-test-coverage]
  - [go-test-coverage configuration]
  - [go-test-coverage badge]

[go-test-darwin.yaml]: ../workflows/README.md#go-test-darwinyaml
[go-test-linux.yaml]: ../workflows/README.md#go-test-linuxyaml
[go-test-windows.yaml]: ../workflows/README.md#go-test-windowsyaml
[testcoverage.yaml]: testcoverage.yaml
[go-test-coverage]: https://github.com/vladopajic/go-test-coverage
[go-test-coverage configuration]: https://github.com/vladopajic/go-test-coverage?tab=readme-ov-file#config
[go-test-coverage badge]: https://github.com/vladopajic/go-test-coverage/blob/main/docs/badge.md
